pub enum LinkerMode {
Internal,
System(String),
}Expand description
Which linker to use for the final linking phase.
The Gruel compiler can either use its built-in ELF linker or delegate to
an external system linker like clang, gcc, or ld.
Variants
Internal
Use the internal linker (default).
System(String)
Use an external system linker (e.g., “clang”, “ld”, “gcc”).