TokenKind

Enum TokenKind 

pub enum TokenKind {
Show 86 variants Fn, Let, Mut, Inout, Borrow, If, Else, Match, While, For, In, Loop, Break, Continue, Return, True, False, Struct, Enum, Drop, Linear, SelfValue, SelfType, Comptime, ComptimeUnroll, Pub, Const, Checked, Unchecked, Ptr, I8, I16, I32, I64, Isize, U8, U16, U32, U64, Usize, F16, F32, F64, Bool, Underscore, Int(u64), Float(u64), String(Spur), Ident(Spur), Plus, Minus, Star, Slash, Percent, Eq, EqEq, Bang, BangEq, Lt, Gt, LtEq, GtEq, AmpAmp, PipePipe, Amp, Pipe, Caret, Tilde, LtLt, GtGt, LParen, RParen, LBrace, RBrace, LBracket, RBracket, Arrow, FatArrow, ColonColon, Colon, Semi, Comma, Dot, At, AtImport(Spur), Eof,
}
Token kinds in the Gruel language.

This enum is Copy since all variants contain only small, copyable data:

  • Most variants are unit (no data)
  • Int contains a u64 (8 bytes)
  • Ident and String contain a Symbol (4 bytes, an interned string handle)

Variants



Fn



Let



Mut



Inout



Borrow



If



Else



Match



While



For



In



Loop



Break



Continue



Return



True



False



Struct



Enum



Drop



Linear



SelfValue



SelfType



Comptime



ComptimeUnroll



Pub



Const



Checked



Unchecked



Ptr



I8



I16



I32



I64



Isize



U8



U16



U32



U64



Usize



F16



F32



F64



Bool



Underscore



Int(u64)



Float(u64)

Floating-point literal, stored as f64 bits for Eq/Copy compatibility. Use f64::from_bits() to recover the value.



String(Spur)



Ident(Spur)



Plus



Minus



Star



Slash



Percent



Eq



EqEq



Bang



BangEq



Lt



Gt



LtEq



GtEq



AmpAmp



PipePipe



Amp



Pipe



Caret



Tilde



LtLt



GtGt



LParen



RParen



LBrace



RBrace



LBracket



RBracket



Arrow



FatArrow



ColonColon



Colon



Semi



Comma



Dot



At



AtImport(Spur)



Eof

Implementations

Source

impl TokenKind

pub fn name(&self) -> &'static str

Get a human-readable name for this token kind.