pub enum WarningKind {
UnusedVariable(String),
UnusedFunction(String),
UnreachableCode,
UnreachablePattern(String),
ComptimeDbgPresent(String),
}Expand description
The kind of compilation warning.
Variants
UnusedVariable(String)
A variable was declared but never used.
UnusedFunction(String)
A function was declared but never called.
UnreachableCode
Code that will never be executed.
UnreachablePattern(String)
A pattern that will never be matched because a previous pattern already covers it.
ComptimeDbgPresent(String)
A comptime-evaluated @dbg call was present during compilation.
Implementations
Sourceimpl WarningKind
impl WarningKind
Sourcepub fn unused_variable_name(&self) -> Option<&str>
pub fn unused_variable_name(&self) -> Option<&str>
Returns the variable name if this is an UnusedVariable warning.
Sourcepub fn format_with_line(&self, line_number: Option<usize>) -> String
pub fn format_with_line(&self, line_number: Option<usize>) -> String
Format the warning message with an optional line number.
When line_number is Some, the line number is appended to the message
for warnings that have a name (like unused variables). This helps
disambiguate when multiple variables share the same name.