pub fn parse_all_files_with_preview(
sources: &[SourceFile<'_>],
preview_features: &PreviewFeatures,
) -> MultiErrorResult<ParsedProgram>Expand description
Parse all files with an explicit set of preview features for the parser (ADR-0049).
pub fn parse_all_files_with_preview(
sources: &[SourceFile<'_>],
preview_features: &PreviewFeatures,
) -> MultiErrorResult<ParsedProgram>Parse all files with an explicit set of preview features for the parser (ADR-0049).