Struct Ast
pub struct Ast {
pub module_doc: Option<Doc>,
pub items: Vec<Item>,
}Expand description
A complete source file (list of items).
Fields
module_doc: Option<Doc>ADR-0089: module-level docstring, if the first doc block in the file was separated from the first item by a blank line.
items: Vec<Item>Trait Implementations
impl<'de> Deserialize<'de> for Ast
impl<'de> Deserialize<'de> for Ast
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Ast, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Ast, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl RemapSpurs for Ast
impl RemapSpurs for Ast
fn remap_spurs(&mut self, table: &[Spur])
impl Serialize for Ast
impl Serialize for Ast
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for Ast
impl StructuralPartialEq for Ast