MultiFileJsonFormatter

Struct MultiFileJsonFormatter 

pub struct MultiFileJsonFormatter<'a> { /* private fields */ }
Formats diagnostics as JSON for machine consumption.

Maps FileIds to their source information, enabling correct file path and line/column output for diagnostics spanning one or more files.

Example

use gruel_compiler::{MultiFileJsonFormatter, SourceInfo, FileId};

let sources = vec![
    (FileId::new(1), SourceInfo::new(&source1, "main.gruel")),
    (FileId::new(2), SourceInfo::new(&source2, "utils.gruel")),
];

let formatter = MultiFileJsonFormatter::new(sources);
let json = formatter.format_error(&error).to_json();

Implementations

Source

impl<'a> MultiFileJsonFormatter<'a>

pub fn new(sources: impl IntoIterator<Item = (FileId, SourceInfo<'a>)>) -> Self

Create a new multi-file JSON diagnostic formatter.

pub fn format_error(&self, error: &CompileError) -> JsonDiagnostic

Format a compile error as JSON.

pub fn format_warning(&self, warning: &CompileWarning) -> JsonDiagnostic

Format a compile warning as JSON.

pub fn format_errors(&self, errors: &CompileErrors) -> String

Format multiple errors as a JSON array string.

pub fn format_warnings(&self, warnings: &[CompileWarning]) -> String

Format multiple warnings as a JSON array string.