Struct Spur
pub struct Spur { /* private fields */ }Expand description
The default key for every Rodeo, uses only 32 bits of space
Internally is a NonZeroU32 to allow for space optimizations when stored inside of an Option
Implementations
impl Spur
impl Spur
pub const fn into_inner(self) -> NonZero<u32>
pub const fn into_inner(self) -> NonZero<u32>
Returns the NonZeroU32 backing the current Spur