pub type MultiErrorResult<T> = Result<T, CompileErrors>;Expand description
Result type for operations that can produce multiple errors.
Aliased Type
pub enum MultiErrorResult<T> {
Ok(T),
Err(CompileErrors),
}pub type MultiErrorResult<T> = Result<T, CompileErrors>;Result type for operations that can produce multiple errors.
pub enum MultiErrorResult<T> {
Ok(T),
Err(CompileErrors),
}