ErrorKind

Enum ErrorKind 

pub enum ErrorKind {
Show 86 variants UnexpectedCharacter(char), InvalidInteger, InvalidFloat, InvalidStringEscape(char), UnterminatedString, UnexpectedToken { expected: Cow<'static, str>, found: Cow<'static, str>, }, UnexpectedEof { expected: Cow<'static, str>, }, ParseError(String), NoMainFunction, UndefinedVariable(String), UndefinedFunction(String), AssignToImmutable(String), UnknownType(String), UseAfterMove(String), CannotMoveField { type_name: String, field: String, }, TypeMismatch { expected: String, found: String, }, WrongArgumentCount { expected: usize, found: usize, }, MissingFields(Box<MissingFieldsError>), UnknownField { struct_name: String, field_name: String, }, DuplicateField { struct_name: String, field_name: String, }, MissingFieldInDestructure { struct_name: String, field: String, }, EmptyStruct, EmptyAnonEnum, CopyStructNonCopyField(Box<CopyStructNonCopyFieldError>), ReservedTypeName { type_name: String, }, DuplicateTypeDefinition { type_name: String, }, LinearValueNotConsumed(String), LinearStructCopy(String), HandleStructMissingMethod { struct_name: String, }, HandleMethodWrongSignature { struct_name: String, found_signature: String, }, DuplicateMethod { type_name: String, method_name: String, }, UndefinedMethod { type_name: String, method_name: String, }, UndefinedAssocFn { type_name: String, function_name: String, }, MethodCallOnNonStruct { found: String, method_name: String, }, MethodCalledAsAssocFn { type_name: String, method_name: String, }, AssocFnCalledAsMethod { type_name: String, function_name: String, }, DuplicateDestructor { type_name: String, }, DestructorUnknownType { type_name: String, }, DuplicateConstant { name: String, kind: String, }, ConstExprNotSupported { expr_kind: String, }, DuplicateVariant { enum_name: String, variant_name: String, }, UnknownVariant { enum_name: String, variant_name: String, }, UnknownEnumType(String), FieldWrongOrder(Box<FieldWrongOrderError>), FieldAccessOnNonStruct { found: String, }, InvalidAssignmentTarget, InoutNonLvalue, InoutExclusiveAccess { variable: String, }, BorrowNonLvalue, MutateBorrowedValue { variable: String, }, MoveOutOfBorrow { variable: String, }, BorrowInoutConflict { variable: String, }, InoutKeywordMissing, BorrowKeywordMissing, BreakOutsideLoop, BreakInConsumingForLoop { element_type: String, }, ContinueOutsideLoop, IntrinsicRequiresChecked(String), UncheckedCallRequiresChecked(String), NonExhaustiveMatch, EmptyMatch, InvalidMatchType(String), UnknownIntrinsic(String), IntrinsicWrongArgCount { name: String, expected: usize, found: usize, }, IntrinsicTypeMismatch(Box<IntrinsicTypeMismatchError>), ImportRequiresStringLiteral, ModuleNotFound { path: String, candidates: Vec<String>, }, StdLibNotFound, PrivateMemberAccess { item_kind: String, name: String, }, UnknownModuleMember { module_name: String, member_name: String, }, LiteralOutOfRange { value: u64, ty: String, }, CannotNegateUnsigned(String), ChainedComparison, IndexOnNonArray { found: String, }, ArrayLengthMismatch { expected: u64, found: u64, }, IndexOutOfBounds { index: i64, length: u64, }, TypeAnnotationRequired, MoveOutOfIndex { element_type: String, }, LinkError(String), UnsupportedTarget(String), PreviewFeatureRequired { feature: PreviewFeature, what: String, }, ComptimeEvaluationFailed { reason: String, }, ComptimeArgNotConst { param_name: String, }, ComptimeUserError(String), InternalError(String), InternalCodegenError(String),
}
The kind of compilation error.

Variants



UnexpectedCharacter(char)



InvalidInteger



InvalidFloat



InvalidStringEscape(char)



UnterminatedString



UnexpectedToken

Fields

expected: Cow<'static, str>
found: Cow<'static, str>


UnexpectedEof

Fields

expected: Cow<'static, str>


ParseError(String)

A custom parse error with a specific message.

Used for parser-generated errors that don’t fit the “expected X, found Y” pattern.



NoMainFunction



UndefinedVariable(String)



UndefinedFunction(String)



AssignToImmutable(String)



UnknownType(String)



UseAfterMove(String)

Use of a value after it has been moved.



CannotMoveField

Attempt to move a non-copy field out of a struct (banned by ADR-0036).

Fields

type_name: String
field: String


TypeMismatch

Fields

expected: String
found: String


WrongArgumentCount

Fields

expected: usize
found: usize


MissingFields(Box<MissingFieldsError>)



UnknownField

Fields

struct_name: String
field_name: String


DuplicateField

Fields

struct_name: String
field_name: String


MissingFieldInDestructure

Missing field in struct destructuring pattern

Fields

struct_name: String
field: String


EmptyStruct

Anonymous struct with no fields is not allowed



EmptyAnonEnum

Anonymous enum with no variants is not allowed



CopyStructNonCopyField(Box<CopyStructNonCopyFieldError>)

@copy struct contains a field with non-Copy type



ReservedTypeName

User-defined type collides with a built-in type name

Fields

type_name: String


DuplicateTypeDefinition

Duplicate type definition

Fields

type_name: String


LinearValueNotConsumed(String)

Linear value was not consumed before going out of scope



LinearStructCopy(String)

Linear struct cannot be marked @copy



HandleStructMissingMethod

@handle struct missing required .handle() method

Fields

struct_name: String


HandleMethodWrongSignature

@handle struct’s .handle() method has wrong signature

Fields

struct_name: String
found_signature: String


DuplicateMethod

Duplicate method definition in impl blocks for the same type

Fields

type_name: String
method_name: String


UndefinedMethod

Method not found on a type

Fields

type_name: String
method_name: String


UndefinedAssocFn

Associated function not found on a type

Fields

type_name: String
function_name: String


MethodCallOnNonStruct

Method call on non-struct type

Fields

found: String
method_name: String


MethodCalledAsAssocFn

Calling a method (with self) as an associated function

Fields

type_name: String
method_name: String


AssocFnCalledAsMethod

Calling an associated function (without self) as a method

Fields

type_name: String
function_name: String


DuplicateDestructor

Duplicate destructor for the same type

Fields

type_name: String


DestructorUnknownType

Destructor for unknown type

Fields

type_name: String


DuplicateConstant

Duplicate constant declaration

Fields

name: String
kind: String


ConstExprNotSupported

Expression not supported in const context

Fields

expr_kind: String


DuplicateVariant

Fields

enum_name: String
variant_name: String


UnknownVariant

Fields

enum_name: String
variant_name: String


UnknownEnumType(String)



FieldWrongOrder(Box<FieldWrongOrderError>)



FieldAccessOnNonStruct

Fields

found: String


InvalidAssignmentTarget



InoutNonLvalue

Inout argument is not an lvalue (variable, field, or array element)



InoutExclusiveAccess

Same variable passed to multiple inout parameters in a single call

Fields

variable: String


BorrowNonLvalue

Borrow argument is not an lvalue (variable, field, or array element)



MutateBorrowedValue

Cannot mutate a borrowed value

Fields

variable: String


MoveOutOfBorrow

Cannot move out of a borrowed value

Fields

variable: String


BorrowInoutConflict

Same variable passed to both borrow and inout parameters (law of exclusivity)

Fields

variable: String


InoutKeywordMissing

Argument to inout parameter is missing inout keyword at call site



BorrowKeywordMissing

Argument to borrow parameter is missing borrow keyword at call site



BreakOutsideLoop



BreakInConsumingForLoop

Fields

element_type: String


ContinueOutsideLoop



IntrinsicRequiresChecked(String)



UncheckedCallRequiresChecked(String)



NonExhaustiveMatch



EmptyMatch



InvalidMatchType(String)



UnknownIntrinsic(String)



IntrinsicWrongArgCount

Fields

name: String
expected: usize
found: usize


IntrinsicTypeMismatch(Box<IntrinsicTypeMismatchError>)



ImportRequiresStringLiteral



ModuleNotFound

Fields

path: String
candidates: Vec<String>

Candidates that were tried (for error message)



StdLibNotFound



PrivateMemberAccess

Fields

item_kind: String
name: String


UnknownModuleMember

Fields

module_name: String
member_name: String


LiteralOutOfRange

Fields

value: u64


CannotNegateUnsigned(String)



ChainedComparison



IndexOnNonArray

Fields

found: String


ArrayLengthMismatch

Fields

expected: u64
found: u64


IndexOutOfBounds

Fields

index: i64
length: u64


TypeAnnotationRequired



MoveOutOfIndex

Cannot move non-Copy element out of array index position

Fields

element_type: String


LinkError(String)



UnsupportedTarget(String)



PreviewFeatureRequired

Fields

what: String


ComptimeEvaluationFailed

Fields

reason: String


ComptimeArgNotConst

Fields

param_name: String


ComptimeUserError(String)



InternalError(String)



InternalCodegenError(String)

Implementations

Source

impl ErrorKind

pub fn code(&self) -> ErrorCode

Get the error code for this error kind.

Every error kind has a unique, stable error code that can be used for documentation lookup and searchability.