pub struct MultiFileJsonFormatter<'a> { /* private fields */ }Expand description
Formats diagnostics as JSON for machine consumption.
Maps FileIds to their source information, enabling correct file path and line/column output for diagnostics spanning one or more files.
Example
ⓘ
use gruel_compiler::{MultiFileJsonFormatter, SourceInfo, FileId};
let sources = vec![
(FileId::new(1), SourceInfo::new(&source1, "main.gruel")),
(FileId::new(2), SourceInfo::new(&source2, "utils.gruel")),
];
let formatter = MultiFileJsonFormatter::new(sources);
let json = formatter.format_error(&error).to_json();Implementations
Sourceimpl<'a> MultiFileJsonFormatter<'a>
impl<'a> MultiFileJsonFormatter<'a>
Sourcepub fn new(sources: impl IntoIterator<Item = (FileId, SourceInfo<'a>)>) -> Self
pub fn new(sources: impl IntoIterator<Item = (FileId, SourceInfo<'a>)>) -> Self
Create a new multi-file JSON diagnostic formatter.
Sourcepub fn format_error(&self, error: &CompileError) -> JsonDiagnostic
pub fn format_error(&self, error: &CompileError) -> JsonDiagnostic
Format a compile error as JSON.
Sourcepub fn format_warning(&self, warning: &CompileWarning) -> JsonDiagnostic
pub fn format_warning(&self, warning: &CompileWarning) -> JsonDiagnostic
Format a compile warning as JSON.
Sourcepub fn format_errors(&self, errors: &CompileErrors) -> String
pub fn format_errors(&self, errors: &CompileErrors) -> String
Format multiple errors as a JSON array string.
Sourcepub fn format_warnings(&self, warnings: &[CompileWarning]) -> String
pub fn format_warnings(&self, warnings: &[CompileWarning]) -> String
Format multiple warnings as a JSON array string.