pub struct Parser { /* private fields */ }Expand description
Chumsky-based parser that converts tokens into an AST.
Implementations
Sourceimpl ChumskyParser
impl ChumskyParser
Sourcepub fn new(tokens: Vec<Token>, interner: ThreadedRodeo) -> ChumskyParser
pub fn new(tokens: Vec<Token>, interner: ThreadedRodeo) -> ChumskyParser
Create a new parser from tokens and an interner produced by the lexer.
Sourcepub fn parse(self) -> Result<(Ast, ThreadedRodeo), CompileErrors>
pub fn parse(self) -> Result<(Ast, ThreadedRodeo), CompileErrors>
Parse the tokens into an AST, returning the AST and the interner.
Returns all parse errors if parsing fails, not just the first one.